# linregmc package  (Linear regression with Monte Carlo error analysis)

This package is a single module which contains three functions

createmcdata - introduce noise in the data based on known experimental precision
linreg       - perform multiple linear regressions and calculate goodness-of-fit
errconf      - get confidence intervals, plot distributions etc.

TODO: Add detailed documentation here
